#!/usr/bin/python
import os, sys, re, glob, argparse
import numpy as np
import matplotlib
matplotlib.use('Agg')
import matplotlib.pyplot as plt
from matplotlib.backends.backend_pdf import PdfPages
pdf = PdfPages("plot.pdf")
util = os.path.join(os.environ["TUTORIALS"],
    "Tutorial_4/utilities")
sys.path.insert(0, util)
import parse_aims

p = argparse.ArgumentParser()
p.add_argument("-d", "--dir", default="RUN.1", dest="maindir")
args = p.parse_args()

os.chdir(args.maindir)

kcal = 627.509
results = []
for rundir in glob.glob("*"): # for all directories
    # get distance from a dir name
    dist, = re.match(r"([\d\.]+)", rundir).groups()
    dist = float(dist) # convert from string to float
    output = os.path.join(rundir, "RUN.1", "aims.out") # AIMS output file
    with open(output) as f: # read and parse the output
        results.append((dist, parse_aims.AIMS_output(f).results))
    enes = results[-1][1]['Energies']
    with open(os.path.join(rundir, 'ts.out')) as f:
        enes['Total energy + TS energy'] = enes['DFT energy']+float(f.read())
results = sorted(results) # sort by distance
methods = ["DFT energy", "Total energy + TS energy", "Total energy + MBD@rsSCS energy"]
dists = []
energies = {method: [] for method in methods}
for dist, data in results:
    if dist == 0: # if monomer, save the data in a special variable
        momoner = {method: data["Energies"][method] for method in methods}
    else:
        dists.append(dist) # 
        for method in methods: # calculate interaction energy for each method
            energies[method].append(data["Energies"][method]-2*momoner[method])
dists = np.array(dists)
for method in energies:
    energies[method] = kcal*np.array(energies[method])
os.chdir("..")

for method in methods:
    plt.plot(dists, energies[method]) # plot each method
plt.plot([3.87], [-1.71], "o") # add a point for CCDS(T) value
plt.legend(methods + ["CCSD(T)"], numpoints=1) # make legend
plt.title("Interaction curve of stacked benzene dimer")
plt.xlabel("distance (angstrom)")
plt.ylabel("energy (kcal/mol)")
pdf.savefig()
pdf.close()
