#!/usr/bin/python
import os, sys, re, glob, argparse, csv
import numpy as np
util = os.path.join(os.environ["TUTORIALS"],
    "Tutorial_4/utilities")
sys.path.insert(0, util)
import parse_aims, prettytable

p = argparse.ArgumentParser()
p.add_argument("-d", "--dir", default="RUN.1", dest="maindir")
args = p.parse_args()

benchmark = {}
with open("bz-dimer.energies.csv") as f:
    csvreader = csv.DictReader(f)
    for row in csvreader:
        benchmark[row["label"]] = float(row["energy"])

os.chdir(args.maindir)

kcal = 627.509
results = []
for rundir in glob.glob("*"):
    geom = rundir
    output = os.path.join(rundir, "RUN.1", "aims.out")
    with open(output) as f:
        results.append((geom, parse_aims.AIMS_output(f).results))
    enes = results[-1][1]['Energies']
    with open(os.path.join(rundir, 'ts.out')) as f:
        enes['Total energy + TS energy'] = enes['DFT energy']+float(f.read())
results = sorted(results)
results.insert(0, results.pop(-1))
labels = ["DFT energy", "Total energy + TS energy", "Total energy + MBD@rsSCS energy"]
header = ["label"] + [re.search(r"([\w@]+) energy$", label).group(1) for label in labels] + ["CCSD(T)"]
tab = prettytable.PrettyTable(header)
tab.align = "r"
tab.align["label"] = "l"
tab.float_format = ".3"
add_label = {"S3": "T", "S8": "S", "M1": "PD"}
for geom, data in results:
    if geom == "benzene":
        momoner = {label: data["Energies"][label] for label in labels}
    else:
        tab.add_row(["{} (= {})".format(geom, add_label[geom]) if geom in add_label else geom]
                    + [kcal*(data["Energies"][label]-2*momoner[label]) for label in labels]
                    + [benchmark[geom]])
print(tab)
