#!/usr/bin/python 
import os, sys, argparse, re
import numpy as np
util = os.path.join(os.environ["TUTORIALS"],
    "Tutorial_4/utilities")
sys.path.insert(0, util)
import geom

# parse command-line arguments
p = argparse.ArgumentParser()
p.add_argument("nproc", type=int)
p.add_argument("--dry", action="store_true")
args = p.parse_args()


# load benzene dimer structures from a text file
geoms = {}
with open("bz-dimer.geoms.txt") as f:
    geom_strings = re.split(r"\n-+\n", f.read()) # split on --- lines
    for s in geom_strings:
        label, xyz = s.split("\n", 1) # split first line with a label
        # parse xyz geometry
        geoms[label.strip()] = geom.Molecule().from_str(xyz, fmt="xyz")


# create a run directory RUN.<n>
i_run = 1
rundir = "RUN.{}".format(i_run)
os.chdir(rundir)

rCC, rCH = 1.3914, 1.0802
CH = geom.Molecule([geom.Atom("C", (rCC, 0, 0)),
                    geom.Atom("H", (rCC+rCH, 0, 0))])
benzene = geom.Molecule()
for angle in np.arange(0, 360, 60):
    benzene.atoms.extend(CH.rotate("z", angle, center=(0, 0, 0)).atoms)


# loop over distances, 0 is for a single molecule
for label in ["benzene"] + list(geoms.keys()):
    if label == "benzene":
        m = benzene
    else:
        m = geoms[label]
    subdir = label
    print(subdir)
    os.chdir(subdir)
    if not args.dry:
        os.system("{0}/mbd/pymbd.py {0}/ts_script.py 2>ts.out".format(util))
    os.chdir("..")




