#!/usr/bin/python
import os, sys, argparse, re
import numpy as np
util = os.path.join(os.environ["TUTORIALS"],
    "Tutorial_4/utilities")
sys.path.insert(0, util)
import geom

p = argparse.ArgumentParser()
p.add_argument("nproc", type=int)
p.add_argument("--dry", action="store_true")
args = p.parse_args()

with open("control.in") as f:
    control = f.read()

# load benzene dimer structures from a text file
geoms = {}
with open("bz-dimer.geoms.txt") as f:
    geom_strings = re.split(r"\n-+\n", f.read()) # split on --- lines
    for s in geom_strings:
        label, xyz = s.split("\n", 1) # split first line with a label
        # parse xyz geometry
        geoms[label.strip()] = geom.Molecule().from_str(xyz, fmt="xyz")

i_run = 1
while True:
    rundir = "RUN.{}".format(i_run)
    if not os.path.exists(rundir):
        break
    i_run += 1
os.mkdir(rundir)
os.chdir(rundir)

rCC, rCH = 1.3914, 1.0802
CH = geom.Molecule([geom.Atom("C", (rCC, 0, 0)),
                    geom.Atom("H", (rCC+rCH, 0, 0))])
benzene = geom.Molecule()
for angle in np.arange(0, 360, 60):
    benzene.atoms.extend(CH.rotate("z", angle, center=(0, 0, 0)).atoms)

for label in ["benzene"] + list(geoms.keys()):
    if label == "benzene":
        m = benzene
    else:
        m = geoms[label]
    subdir = label
    print(subdir)
    os.mkdir(subdir)
    os.chdir(subdir)
    with open("control.in", "w") as f:
        print(control.format(), file=f)
    with open("geometry.in", "w") as f:
        print(m.to_str("aims"), file=f)
    if not args.dry:
        os.system("{}/run_aims.sh -b light -n {} > /dev/null".format(util, args.nproc))
#        os.system("{0}/mbd/pymbd.py {0}/ts_script.py 2>ts.out".format(util))
    os.chdir("..")
