#!/usr/bin/python 
import os, sys, argparse
import numpy as np
util = os.path.join(os.environ["TUTORIALS"],
    "Tutorial_4/utilities")
sys.path.insert(0, util)
import geom

# parse command-line arguments
p = argparse.ArgumentParser()
p.add_argument("nproc", type=int)
p.add_argument("--dry", action="store_true")
args = p.parse_args()

# read a control.in file
with open("control.in") as f:
    control = f.read()

# create a run directory RUN.<n>
i_run = 1
while True:
    rundir = "RUN.{}".format(i_run)
    if not os.path.exists(rundir):
        break
    i_run += 1
os.mkdir(rundir)
os.chdir(rundir)

# build benzene molecule
rCC, rCH = 1.397, 1.084
CH = geom.Molecule([geom.Atom("C", (rCC, 0, 0)),
                    geom.Atom("H", (rCC+rCH, 0, 0))])
benzene = geom.Molecule()
for angle in np.arange(0, 360, 60):
    benzene.atoms.extend(CH.rotate("z", angle, center=(0, 0, 0)).atoms)

# loop over distances, 0 is for a single molecule
for dist in [0, 3.2, 3.4, 3.6, 3.8, 4, 4.4, 4.8, 5.6]:
    if dist == 0:
        m = benzene
    else:
        m = benzene.join(benzene.shift((0, 0, dist)))
    subdir = "{}".format(dist)
    print(subdir)
    os.mkdir(subdir)
    os.chdir(subdir)
    with open("control.in", "w") as f:
        print(control, file=f)
    with open("geometry.in", "w") as f:
        print(m.to_str("aims"), file=f)
    if not args.dry:
        os.system("{}/run_aims.sh -b light -n {} > /dev/null".format(util, args.nproc))
#        os.system("module purge")
        os.system("{0}/mbd/pymbd.py {0}/ts_script.py 2>ts.out".format(util))
    os.chdir("..")
