
from itertools import dropwhile
import numpy as np


def hirshfeld_volumes(lines):
    for line in lines:
        if not line.strip():
            return
        if 'Free atom volume' in line:
            free = float(line.split()[-1])
        elif 'Hirshfeld volume' in line:
            hirsh = float(line.split()[-1])
            yield hirsh/free


def run(ctx, mbd):
    bohr = mbd.bohr
    mbd.param_ts_energy_accuracy = 1e-6
    with open('geometry.in') as f:
        lines = [l.split() for l in f if l.lstrip()[0] != '#']
        species = [line[4] for line in lines if line[0] == 'atom']
        coords = [[float(x)/bohr for x in line[1:4]] for line in lines if line[0] == 'atom']
        latt_vectors = [[float(x)/bohr for x in line[1:4]] for line in lines if line[0] == 'lattice_vector']
    with open('RUN.1/aims.out') as f:
        lines = dropwhile(lambda l: 'Hirshfeld analysis' not in l, f)
        hirsh = np.array(list(hirshfeld_volumes(lines)))
    alpha_0_free, C6_free, R_vdw_free = ctx.get_free_atom_data(species)
    alpha_0, C6, R_vdw = [x*hirsh**fac for x, fac in
                          zip([alpha_0_free, C6_free, R_vdw_free],
                              [1, 2, 1/3])]
    if latt_vectors:
        assert len(latt_vectors) == 3
        ctx.printerr(mbd.get_ts_energy('C', 'fermi', coords, C6, alpha_0, R_vdw, s_r=0.94, d=20,
                    unit_cell=latt_vectors))
    else:
        ctx.printerr(mbd.get_ts_energy('', 'fermi', coords, C6, alpha_0, R_vdw, s_r=0.94, d=20))
